class DataProcessor:
    def __init__(self, data):
        self.data = data

    def sum(self):
        return sum(self.data)

    def average(self):
        return sum(self.data) / len(self.data) if self.data else 0



import unittest
from my_sample_package.data_processor import DataProcessor

class TestDataProcessor(unittest.TestCase):
    def setUp(self):
        self.data = [1, 2, 3, 4, 5]
        self.processor = DataProcessor(self.data)

    def test_sum(self):
        self.assertEqual(self.processor.sum(), 15)

    def test_average(self):
        self.assertEqual(self.processor.average(), 3)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='moshe-my-sample-package',
    version='0.1',
    packages=find_packages(),
    install_requires=[],
    test_suite='tests',
    author='Moshe Eliya',
    author_email='',
)



import unittest
from my_sample_package.calculator import Calculator

class TestCalculator(unittest.TestCase):
    def setUp(self):
        self.calc = Calculator()

    def test_add(self):
        self.assertEqual(self.calc.add(2, 3), 5)
        self.assertEqual(self.calc.add(-1, 1), 0)

    def test_subtract(self):
        self.assertEqual(self.calc.subtract(3, 2), 1)
        self.assertEqual(self.calc.subtract(-1, 1), -2)

    def test_multiply(self):
        self.assertEqual(self.calc.multiply(2, 3), 6)
        self.assertEqual(self.calc.multiply(-1, 1), -1)

    def test_divide(self):
        self.assertEqual(self.calc.divide(6, 3), 2)
        with self.assertRaises(ValueError):
            self.calc.divide(1, 0)

if __name__ == '__main__':
    unittest.main()
